from fastapi import APIRouter, Depends, status
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.contact_form import ContactFormCreate, ContactFormSchema
from helpers.contact_form_helpers import handle_contact_form_submission

router = APIRouter()

@router.post("/email", status_code=status.HTTP_201_CREATED, response_model=ContactFormSchema)
async def submit_contact_form(
    form_data: ContactFormCreate,
    db: Session = Depends(get_db)
):
    """
    Handle contact form submission with validation.
    
    All fields (name, email, message) are required.
    Email must be in valid format.
    """
    return handle_contact_form_submission(db=db, form_data=form_data)